@@ -19,7 +19,7 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.28.1"
+VERSION    = "2.29.2"
 LOCALEDIR = "/usr/local/share/locale"
 DATADIR    = "/usr/local/share"
 SYSCONFDIR = "/usr/local/etc"
@@ -53,7 +53,7 @@ NOLOGIN_SHELL = "/sbin/nologin"
 SKEL_HOMEDIR  = "/etc/skel"
 
 XEPHYR_ARGV  = [ "/usr/bin/Xephyr", "-terminate", "-audit", "0", "-nolisten", "tcp", "-name", "sabayon" ]
-SESSION_ARGV = [ "/etc/gdm/Xsession", "gnome" ]
+SESSION_ARGV = [ "/etc/gdm/Xsession", "gnome-session" ]
 USERMOD_ARGV = [ "/usr/sbin/usermod" ]
 
 PANEL_KEY_BASE = "/apps/panel"
